==> kubernetes-model-storageclass-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/storage/v1beta1/CSINodeListBuilder.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSINodeListBuilder extends io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluentImpl<io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListBuilder>{
  public CSINodeListBuilder() {
    this(false);
  }
  public CSINodeListBuilder(java.lang.Boolean validationEnabled) {
    this(new CSINodeList(), validationEnabled);
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluent<?> fluent) {
    this(fluent, false);
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSINodeList(), validationEnabled);
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList instance) {
    this(fluent, instance, false);
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList instance) {
    this(instance,false);
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList build() {
    CSINodeList buildable = new CSINodeList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSINodeListBuilder that = (CSINodeListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-storageclass-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/storage/v1beta1/CSINodeListBuilder.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSINodeListBuilder extends io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluentImpl<io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListBuilder>{
  public CSINodeListBuilder() {
    this(false);
  }
  public CSINodeListBuilder(java.lang.Boolean validationEnabled) {
    this(new CSINodeList(), validationEnabled);
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluent<?> fluent) {
    this(fluent, false);
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSINodeList(), validationEnabled);
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList instance) {
    this(fluent, instance, false);
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList instance) {
    this(instance,false);
  }
  public CSINodeListBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeList build() {
    CSINodeList buildable = new CSINodeList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSINodeListBuilder that = (CSINodeListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
